@@ -28,7 +28,7 @@ from fast_sql.fastsql.sql import Read_sql
 
 os.environ["NLS_LANG"] = "SIMPLIFIED CHINESE_CHINA.UTF8"
 
-__version__ = "1.4.0"
+__version__ = "1.4.1"
 
 
 def read_sql(
@@ -43,7 +43,9 @@ def read_sql(
     chunksize=20000,
     parse_dates=None,
     columns=None,
+    columns_upper=True,
     desc="read the scheduler",
+    auto_order=False,
 ):
     """
     Read SQL query or database table into a DataFrame.
@@ -89,6 +91,10 @@ def read_sql(
     columns : list, default: None
         List of column names to select from SQL table (only used when reading
         a table).
+    columns_upper : bool ,default: True
+        returns whether the data column is capitalized
+    auto_order: bool ,default: False
+        Whether  the most final result is sorted
 
     Returns
     -------
@@ -115,6 +121,8 @@ def read_sql(
         show_progress=show_progress,
         chunksize=chunksize,
         desc=desc,
+        columns_upper=columns_upper,
+        auto_order=auto_order,
     )
 
     return Fastsql_builder.read_sql(
@@ -276,10 +284,12 @@ def to_sql(
     params=None,
     parse_dates=None,
     columns=None,
+    columns_upper=True,
     delete_cache=True,
     data_processing=None,
     delete_sql=None,
     desc="rsync the scheduler",
+    auto_order=False,
     **kwargs,
 ):
     """
@@ -349,6 +359,12 @@ def to_sql(
     thread_num: int, default: 15
         Read the number of threads used, recommended based on memory allocation.
     encoding : str, default UTF-8
+        columns_upper : bool ,default: True
+        returns whether the data column is capitalized
+    columns_upper : bool ,default: True
+        returns whether the data column is capitalized
+    auto_order: bool ,default: False
+        Whether  the most final result is sorted
 
     Returns
     -------
@@ -397,6 +413,7 @@ def to_sql(
         to_db=to_db,
         to_table=to_table,
         to_columns=to_columns,
+        columns_upper=columns_upper,
         if_exists=if_exists,
         thread_num=thread_num,
         encoding=encoding,
@@ -410,6 +427,7 @@ def to_sql(
         data_processing=data_processing,
         delete_sql=delete_sql,
         desc=desc,
+        auto_order=auto_order,
         **kwargs,
     )
 
