@@ -22,6 +22,8 @@ class Read_sql:
         show_progress=False,
         chunksize=15000,
         desc=None,
+        columns_upper=True,
+        auto_order=False,
     ):
         if con is not None:
             self.db_pool = Sqlalchemy_Pool(con, num=thread_num + 6, encoding=encoding)
@@ -41,6 +43,8 @@ class Read_sql:
         self.chunksize = chunksize
         self.tqdm_w = None
         self.desc = desc
+        self.columns_upper = columns_upper
+        self.auto_order = auto_order
 
     def read_sql(self, **kwargs):
         con = self.db_pool.get_db()
@@ -49,7 +53,8 @@ class Read_sql:
         self.tqdm_init(self.count, weight=85)
         if self.avg_list is None:
             result = pd.read_sql(self.sql, con, **self.pd_params)
-            result.columns = [i.upper() for i in result.columns.tolist()]
+            if self.columns_upper:
+                result.columns = [i.upper() for i in result.columns.tolist()]
             self.tqdm_update(self.count)
         else:
             task_list, pool = self.start_thread_read()
@@ -57,14 +62,14 @@ class Read_sql:
             result = self.result.pop(0)
             for i in range(len(self.result)):
                 result = result.append(self.result.pop(0), ignore_index=True)
-
-            result.columns = [i.upper() for i in result.columns.tolist()]
+            if self.columns_upper:
+                result.columns = [i.upper() for i in result.columns.tolist()]
 
             if self.driver == "oracle":
                 result.drop("NO", axis=1, inplace=True)
 
-        if self.ordering:
-            result.sort_values([i.strip().upper() for i in self.ordering], inplace=True)
+        if self.auto_order:
+            result.sort_values([i.strip() for i in self.ordering], inplace=True,ascending=self.sort_type)
         self.db_pool.close_db(con)
         self.result.clear()
         return result
@@ -126,11 +131,14 @@ class Read_sql:
         self.count = self.get_query_count(con, self.sql)
         # self.chunksize = self.count // self.thread_num // 2
         # self.tqdm_init(self.count, desc='Read the scheduler', weight=85)
-
-        if "order" in self.sql.lower():
-            buf = self.sql.split("order")
-            self.ordering = buf[1].split("by")[1].strip().split(",")
-            self.sql = buf[0]
+        if self.auto_order:
+            buf = re.search("(?<=order[\s+]by)(.*)(?=limit)",self.sql,re.I)
+            if buf:
+                buf = buf.group()
+                self.sort_type = False if 'desc' in buf.lower() else True
+                buf = buf.replace('desc','').replace('asc','').replace('DESC','').replace('ASC','')
+                self.sql = 'select ' + re.search("(?<=select)(.*)(?=limit)",self.sql,re.I).group()
+                self.ordering = buf.split(',')
 
         if self.count < 2000:
             return None
@@ -391,7 +399,8 @@ class to_sql(Read_sql):
 
     def insert_db(self, path):
         df = pd.read_pickle(path)
-        df.columns = [i.upper() for i in df.columns]
+        if self.columns_upper:
+            df.columns = [i.upper() for i in df.columns]
         if self.data_processing is not None:
             df = self.data_processing(df)
 
